"use strict";
const common_vendor = require("../../common/vendor.js");
const common_assets = require("../../common/assets.js");
const _sfc_main = {
  data() {
    return {
      show: false,
      // 使用Popup组件时,阻止禁止滚动穿透
      productInfo: {
        id: 0,
        name: "",
        price: "0.00",
        market_price: "0.00",
        spec: "",
        stock: 0,
        thumb: "",
        poster: "",
        description: "",
        business_info: {
          name: "",
          logopic: "",
          desc: ""
        },
        product_attr: [],
        product_sku: []
      },
      requestParam: {
        id: 0
      },
      // 数量
      quantity: 1,
      // 总价
      priceTotal: "0.00",
      // 优惠券列表
      couponList: [],
      // 总价
      priceTotal: "0.00",
      // 优惠券使用
      couponUsed: "去使用 >",
      // 扣减金额
      rebatePrice: 0,
      // 已经选择的优惠券ID
      customCoupon: 0,
      // 规格选择按钮类型
      specBtnType: 1,
      // 1预约。2购物车
      // 地址列表
      addrList: [],
      // 已选地址
      checkedAddr: {
        id: 0,
        contact_name: "",
        contact_phone: "",
        contact_province: "",
        contact_city: "",
        contact_area: "",
        contact_addr: "",
        is_default: 0
      },
      // 客服二维码
      followQrcode: "",
      // 是否登录状态
      isShowPrice: false,
      // 选择的skuid
      sku_id: 0,
      StatusBarHeight: 0
      //状态栏高度设定
    };
  },
  onLoad(param) {
    this.requestParam.id = param.product_id;
    var that = this;
    common_vendor.index.$on("addr_list_change", function(data) {
      that.addrList = data.list;
    });
  },
  onShow() {
    this.getStatusBarHeight();
    this.isShowPrice = this.$checkAccess.getFollowQrcode() ? 0 : 1;
    if (this.requestParam.id > 0) {
      this.$http.request("api/product/get_detail", this.requestParam).then((re) => {
        if (re.code == "success") {
          this.productInfo = re.data;
          this.setDefaultSpec();
        }
      });
    }
  },
  methods: {
    // 地址弹出层
    showAddrPopup() {
      this.$refs.addrPopup.open("bottom");
    },
    // 规格弹出层
    showSpecPopup(type) {
      if (!this.$checkAccess.alterLogin())
        return;
      if (this.$checkAccess.getFollowQrcode())
        return this.openAddFollow();
      this.specBtnType = type;
      this.couponUsed = "去使用 >";
      this.rebatePrice = 0;
      this.customCoupon = 0;
      this.priceHandler();
      this.$refs.specPopup.open("bottom");
      this.$http.request("api/custom_coupon/get_checked", this.requestParam).then((re) => {
        if (re.code == "success") {
          this.couponList = re.data;
          this.checkCoupon();
        }
      });
      this.getAddrList();
      if (this.productInfo.product_sku.length === 1) {
        this.defaultSkuStatus();
      }
    },
    // 优惠券弹出层
    openCoupon() {
      this.$refs.couponPopup.open("bottom");
    },
    // 数量调整
    changeQuantity(number) {
      if (number != 0) {
        this.quantity = this.quantity + number;
      }
      if (this.quantity > this.productInfo.stock) {
        this.quantity = this.productInfo.stock;
        common_vendor.index.showToast({
          title: "库存不足",
          icon: "none"
        });
      }
      if (this.quantity < 1) {
        this.quantity = 1;
        common_vendor.index.showToast({ title: "数量不可以小于0", icon: "none" });
      }
      this.priceHandler();
      this.checkCoupon();
    },
    // 创建订单
    createOrder() {
      if (!this.$checkAccess.alertCity())
        return;
      if (this.quantity < 1) {
        common_vendor.index.showToast({
          title: "至少购买1个"
        });
        return;
      }
      if (this.productInfo.stock < 1) {
        common_vendor.index.showToast({
          title: "库存不足",
          icon: "none"
        });
        return;
      }
      if (!this.checkedAddr.id) {
        common_vendor.index.showToast({
          title: "请选择收货地址",
          icon: "none"
        });
        return;
      }
      let productInfo = [{ name: this.productInfo.name, spec: this.productInfo.spec, price: this.productInfo.price }];
      productInfo = JSON.stringify(productInfo);
      let productList = [{ product_id: this.productInfo.id, buy_num: this.quantity, product_skuid: this.sku_id }];
      productList = JSON.stringify(productList);
      this.$http.request("api/orders/create", { "product_list": productList, "custom_coupon_id": this.customCoupon, "addr_id": this.checkedAddr.id }, "post").then((re) => {
        if (re.code == "success") {
          this.productInfo.stock = this.productInfo.stock - this.quantity;
          this.$refs.specPopup.close();
          let orderInfo = re.data;
          orderInfo = JSON.stringify(orderInfo);
          let params = encodeURIComponent(orderInfo);
          common_vendor.index.navigateTo({ url: `/pages/orders/confirm?params=${params}` });
        } else {
          common_vendor.index.showModal({ title: re.msg, showCancel: false });
        }
      });
    },
    // 加入购物车
    createCart() {
      if (!this.$checkAccess.alertCity())
        return;
      if (this.quantity < 1) {
        common_vendor.index.showToast({
          title: "至少购买1个"
        });
        return;
      }
      if (this.productInfo.stock < 1) {
        common_vendor.index.showToast({
          title: "库存不足",
          icon: "none"
        });
        return;
      }
      let data = { product_id: this.productInfo.id, buy_num: this.quantity, skuid: this.sku_id };
      this.$http.request("api/shop_cart/add", data, "post").then((re) => {
        if (re.code == "success") {
          common_vendor.index.showToast({
            icon: "success",
            title: "加入购物车成功"
          });
          this.$refs.specPopup.close();
        } else {
          common_vendor.index.showToast({
            icon: "error",
            title: "加入购物车失败"
          });
        }
      });
    },
    // 检查优惠券是否可用
    checkCoupon() {
      if (this.couponList.length) {
        for (let i in this.couponList) {
          var totalPrice = 0;
          if (this.couponList[i].type_id == 1) {
            var isScope = false;
            for (let k in this.couponList[i].product_scope) {
              if (this.couponList[i].product_scope[k].product_id == this.productInfo.id)
                isScope = true;
            }
            if (isScope)
              totalPrice = this.$decimal.add(totalPrice, this.$decimal.mul(this.productInfo.price, this.quantity));
          } else {
            totalPrice = this.$decimal.add(totalPrice, this.$decimal.mul(this.productInfo.price, this.quantity));
          }
          this.couponList[i].is_std = totalPrice.toFixed() >= this.$decimal.mul(this.couponList[i].std_pay, 1).toFixed();
        }
      }
    },
    // 选择优惠券
    checkedCoupon(index) {
      this.couponList[index].checked = this.couponList[index].checked ? 0 : 1;
      for (let i in this.couponList) {
        if (index != i)
          this.couponList[i].checked = 0;
      }
      if (!this.couponList[index].checked)
        this.couponUsed = "去使用 >";
      this.customCoupon = this.couponList[index].checked ? this.couponList[index].id : 0;
      this.couponRebate();
      this.priceHandler();
      this.$refs.couponPopup.close();
    },
    // 计算价格
    priceHandler() {
      let priceTotal = this.$decimal.mul(this.productInfo.price, this.quantity);
      priceTotal = priceTotal.sub(this.rebatePrice);
      this.priceTotal = priceTotal.toFixed(2);
    },
    // 计算优惠券扣减
    couponRebate() {
      this.rebatePrice = 0;
      for (let i in this.couponList) {
        if (this.couponList[i].id != this.customCoupon) {
          continue;
        }
        var totalPrice = 0;
        if (this.couponList[i].type_id == 1) {
          var isScope = false;
          for (let k in this.couponList[i].product_scope) {
            if (this.couponList[i].product_scope[k].product_id == this.productInfo.id)
              isScope = true;
          }
          if (isScope)
            totalPrice = this.$decimal.mul(this.productInfo.price, this.quantity);
        } else {
          totalPrice = this.$decimal.mul(this.productInfo.price, this.quantity);
        }
        if (totalPrice.toFixed() >= this.$decimal.mul(this.couponList[i].std_pay, 1).toFixed()) {
          let rebatePrice = this.$decimal.mul(1, 0);
          if (this.couponList[i].rebate_type == 1) {
            rebatePrice = this.$decimal.mul(this.couponList[i].rebate, 1);
            this.couponUsed = "￥-" + rebatePrice.toFixed(2);
          }
          if (this.couponList[i].rebate_type == 2) {
            rebatePrice = this.$decimal.mul(totalPrice, this.couponList[i].rebate);
            rebatePrice = this.$decimal.sub(totalPrice, rebatePrice.mul(0.1));
            this.couponUsed = "￥-" + rebatePrice.toFixed(2);
          }
          if (this.couponList[i].rebate_type == 3) {
            this.couponUsed = "送" + (this.couponList[i].rebate_scope.length ? this.couponList[i].rebate_scope[0].product_name : "");
          }
          this.rebatePrice = rebatePrice.toFixed(2);
        }
      }
    },
    popupChange(e) {
      this.show = e.show;
    },
    // 选择地址
    checkedAddrItem(item) {
      this.checkedAddr = item;
      this.$refs.addrPopup.close();
    },
    getAddrList() {
      this.$http.request("api/custom_addr/get_list").then((callback) => {
        if (callback.code == "success") {
          this.addrList = callback.data;
          if (this.addrList.length) {
            for (let i in this.addrList) {
              if (this.addrList[i].is_default)
                this.checkedAddr = this.addrList[i];
            }
            if (!this.checkedAddr.id) {
              this.checkedAddr = this.addrList[this.addrList.length - 1];
            }
          }
        }
      });
    },
    // 客服显示
    openAddFollow() {
      this.followQrcode = this.$checkAccess.getFollowQrcode();
      if (this.followQrcode)
        this.$refs.addFollow.open("center");
    },
    closeAddFollow() {
      this.$refs.addFollow.close();
    },
    // 保存图片
    saveImage() {
      var that = this;
      common_vendor.index.downloadFile({
        url: this.followQrcode,
        success: function(res) {
          if (res.statusCode == 200) {
            common_vendor.index.saveImageToPhotosAlbum({
              filePath: res.tempFilePath,
              success: function(res2) {
                common_vendor.index.showToast({ title: "保存成功", icon: "none" });
                that.$refs.addFollow.close();
              },
              fail: function(err) {
              }
            });
          }
        }
      });
    },
    // 设置默认sku
    setDefaultSpec() {
      if (this.productInfo.product_sku.length) {
        if (this.productInfo.product_sku.length > 1) {
          for (var k = 0; k < this.productInfo.product_sku.length; k++) {
            if (k === this.productInfo.product_sku.length) {
              common_vendor.index.showToast({
                title: "当前商品已全部下架",
                icon: "error"
              });
              this.productInfo.stock = 0;
              return;
            }
            if (this.productInfo.product_sku[k].status === 0) {
              var attr_ids = this.productInfo.product_sku[k].attr_ids.split(",");
              break;
            }
          }
          for (let i in this.productInfo.product_attr) {
            for (let j in this.productInfo.product_attr[i].attr_list) {
              if (attr_ids.includes(this.productInfo.product_attr[i].attr_list[j].id + "")) {
                this.productInfo.product_attr[i].attr_list[j].active = 1;
              } else {
                this.productInfo.product_attr[i].attr_list[j].active = 0;
              }
            }
          }
          this.productInfo.price = this.productInfo.product_sku[k].price;
          this.productInfo.spec = this.productInfo.product_sku[k].attr_names;
          this.productInfo.stock = this.productInfo.product_sku[k].stock;
          this.sku_id = this.productInfo.product_sku[k].id;
          this.priceHandler();
        } else {
          var attr_ids = this.productInfo.product_sku[0].attr_ids.split(",");
          for (let i in this.productInfo.product_attr) {
            for (let j in this.productInfo.product_attr[i].attr_list) {
              if (attr_ids.includes(this.productInfo.product_attr[i].attr_list[j].id + "")) {
                this.productInfo.product_attr[i].attr_list[j].active = 1;
              } else {
                this.productInfo.product_attr[i].attr_list[j].active = 0;
              }
            }
          }
          this.productInfo.price = this.productInfo.product_sku[0].price;
          this.productInfo.spec = this.productInfo.product_sku[0].attr_names;
          this.productInfo.stock = this.productInfo.product_sku[0].stock;
          this.sku_id = this.productInfo.product_sku[0].id;
          this.priceHandler();
        }
      }
    },
    // 属性变更
    attrChange(spec_index, attr_index) {
      if (this.productInfo.product_attr[spec_index].attr_list[attr_index].active)
        return;
      let originalActiveStates = {};
      for (let i in this.productInfo.product_attr[spec_index].attr_list) {
        originalActiveStates[i] = this.productInfo.product_attr[spec_index].attr_list[i].active;
      }
      for (let i in this.productInfo.product_attr[spec_index].attr_list) {
        this.productInfo.product_attr[spec_index].attr_list[i].active = 0;
      }
      this.productInfo.product_attr[spec_index].attr_list[attr_index].active = 1;
      var attr_ids = [];
      for (let i in this.productInfo.product_attr) {
        for (let j in this.productInfo.product_attr[i].attr_list) {
          if (this.productInfo.product_attr[i].attr_list[j].active) {
            attr_ids.push(this.productInfo.product_attr[i].attr_list[j].id);
          }
        }
      }
      var attrids = attr_ids.join(",");
      let currentSKUStatus = 0;
      if (this.productInfo.product_sku.length) {
        let haveSku = 0;
        for (let i in this.productInfo.product_sku) {
          if (this.productInfo.product_sku[i].attr_ids != attrids)
            continue;
          haveSku = 1;
          currentSKUStatus = this.productInfo.product_sku[i].status;
          if (currentSKUStatus === 1) {
            common_vendor.index.showToast({ title: "该规格已下架", icon: "none" });
            for (let k in originalActiveStates) {
              this.productInfo.product_attr[spec_index].attr_list[k].active = originalActiveStates[k];
            }
            continue;
          }
          this.productInfo.price = this.productInfo.product_sku[i].price;
          this.productInfo.spec = this.productInfo.product_sku[i].attr_names;
          this.productInfo.stock = this.productInfo.product_sku[i].stock;
          this.sku_id = this.productInfo.product_sku[i].id;
          this.priceHandler();
        }
        if (!haveSku) {
          common_vendor.index.showToast({ title: "该规格已下架", icon: "none" });
          for (let k in originalActiveStates) {
            this.productInfo.product_attr[spec_index].attr_list[k].active = originalActiveStates[k];
          }
        }
      }
    },
    //只有一组sku默认规格是否已下架
    defaultSkuStatus() {
      if (this.productInfo.product_sku.length) {
        if (this.productInfo.product_sku[0].status === 1) {
          common_vendor.index.showToast({
            title: "该规格已下架",
            icon: "none"
          });
          this.productInfo.stock = 0;
          var attr_ids = this.productInfo.product_sku[0].attr_ids.split(",");
          for (let i in this.productInfo.product_attr) {
            for (let j in this.productInfo.product_attr[i].attr_list) {
              if (attr_ids.includes(this.productInfo.product_attr[i].attr_list[j].id + "")) {
                this.productInfo.product_attr[i].attr_list[j].active = 0;
              }
            }
          }
          return;
        }
      }
    },
    goBack() {
      common_vendor.index.navigateBack({
        success: () => {
        },
        fail: (err) => {
          common_vendor.index.reLaunch({
            url: "/pages/index/index"
          });
        }
      });
    },
    getStatusBarHeight() {
      let SYSTEM_INFO = common_vendor.index.getWindowInfo();
      this.StatusBarHeight = SYSTEM_INFO.statusBarHeight || 10;
    }
  }
};
if (!Array) {
  const _easycom_uni_icons2 = common_vendor.resolveComponent("uni-icons");
  const _easycom_uni_popup2 = common_vendor.resolveComponent("uni-popup");
  (_easycom_uni_icons2 + _easycom_uni_popup2)();
}
const _easycom_uni_icons = () => "../../uni_modules/uni-icons/components/uni-icons/uni-icons.js";
const _easycom_uni_popup = () => "../../uni_modules/uni-popup/components/uni-popup/uni-popup.js";
if (!Math) {
  (_easycom_uni_icons + _easycom_uni_popup)();
}
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: "overflow:" + ($data.show ? "hidden" : "visible"),
    b: common_vendor.p({
      type: "back",
      color: "#fff",
      size: "20"
    }),
    c: $data.StatusBarHeight + "px",
    d: common_vendor.o((...args) => $options.goBack && $options.goBack(...args)),
    e: $data.productInfo.thumb,
    f: $data.isShowPrice
  }, $data.isShowPrice ? {
    g: common_vendor.t($data.productInfo.price),
    h: common_vendor.t($data.productInfo.market_price)
  } : {}, {
    i: common_vendor.t($data.productInfo.name),
    j: common_vendor.t($data.productInfo.spec),
    k: common_vendor.t($data.productInfo.stock),
    l: $data.productInfo.business_info.name
  }, $data.productInfo.business_info.name ? {
    m: $data.productInfo.business_info.logopic,
    n: common_vendor.t($data.productInfo.business_info.name),
    o: common_vendor.t($data.productInfo.business_info.desc)
  } : {}, {
    p: $data.productInfo.description,
    q: $data.productInfo.poster
  }, $data.productInfo.poster ? {
    r: $data.productInfo.poster
  } : {}, {
    s: common_assets._imports_0$1,
    t: common_vendor.o(($event) => $options.showSpecPopup(1)),
    v: common_vendor.o(($event) => $options.showSpecPopup(2)),
    w: $data.specBtnType == 1
  }, $data.specBtnType == 1 ? common_vendor.e({
    x: !$data.checkedAddr.id
  }, !$data.checkedAddr.id ? {} : {}, {
    y: common_vendor.t($data.checkedAddr.contact_name),
    z: common_vendor.t($data.checkedAddr.contact_phone),
    A: common_vendor.t($data.checkedAddr.contact_province),
    B: common_vendor.t($data.checkedAddr.contact_city),
    C: common_vendor.t($data.checkedAddr.contact_area),
    D: common_vendor.t($data.checkedAddr.contact_addr),
    E: common_vendor.o(($event) => $options.showAddrPopup())
  }) : {}, {
    F: $data.productInfo.thumb,
    G: common_vendor.t($data.productInfo.name),
    H: $data.isShowPrice
  }, $data.isShowPrice ? {
    I: common_vendor.t($data.productInfo.price),
    J: common_vendor.t($data.productInfo.market_price)
  } : {}, {
    K: common_assets._imports_1,
    L: common_vendor.o(($event) => $options.changeQuantity(-1)),
    M: common_vendor.o(($event) => $options.changeQuantity(0)),
    N: $data.quantity,
    O: common_vendor.o(($event) => $data.quantity = $event.detail.value),
    P: common_assets._imports_2,
    Q: common_vendor.o(($event) => $options.changeQuantity(1)),
    R: common_vendor.t($data.productInfo.stock),
    S: common_vendor.f($data.productInfo.product_attr, (spec, spec_index, i0) => {
      return {
        a: common_vendor.t(spec.spec_name),
        b: common_vendor.f(spec.attr_list, (option, attr_index, i1) => {
          return {
            a: common_vendor.t(option.name),
            b: common_vendor.n(option.active ? "active" : ""),
            c: attr_index,
            d: common_vendor.o(($event) => $options.attrChange(spec_index, attr_index), attr_index)
          };
        }),
        c: spec_index
      };
    }),
    T: $data.specBtnType == 1
  }, $data.specBtnType == 1 ? {
    U: common_vendor.t($data.couponUsed),
    V: common_vendor.o(($event) => $options.openCoupon())
  } : {}, {
    W: $data.specBtnType == 1
  }, $data.specBtnType == 1 ? {
    X: common_vendor.t($data.priceTotal)
  } : {}, {
    Y: $data.specBtnType == 1
  }, $data.specBtnType == 1 ? {
    Z: common_vendor.o(($event) => $options.createOrder())
  } : {}, {
    aa: $data.specBtnType == 2
  }, $data.specBtnType == 2 ? {
    ab: common_vendor.o(($event) => $options.createCart())
  } : {}, {
    ac: common_vendor.sr("specPopup", "618774e2-1"),
    ad: common_vendor.o($options.popupChange),
    ae: common_vendor.p({
      show: true,
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    }),
    af: common_vendor.f($data.couponList, (item, index, i0) => {
      return common_vendor.e({
        a: item.rebate_type == 1
      }, item.rebate_type == 1 ? {
        b: common_vendor.t(item.rebate)
      } : {}, {
        c: item.rebate_type == 2
      }, item.rebate_type == 2 ? {
        d: common_vendor.t(item.rebate)
      } : {}, {
        e: item.rebate_type == 3
      }, item.rebate_type == 3 ? common_vendor.e({
        f: item.rebate_scope.length
      }, item.rebate_scope.length ? {
        g: common_vendor.t(item.rebate_scope[0].product_name)
      } : {}) : {}, {
        h: common_vendor.t(item.std_pay),
        i: item.rebate_type == 1
      }, item.rebate_type == 1 ? {} : {}, {
        j: item.rebate_type == 2
      }, item.rebate_type == 2 ? {} : {}, {
        k: item.rebate_type == 3
      }, item.rebate_type == 3 ? {} : {}, {
        l: item.type_id == 1
      }, item.type_id == 1 ? {} : {}, {
        m: item.type_id == 2
      }, item.type_id == 2 ? {} : {}, {
        n: !item.is_std
      }, !item.is_std ? {} : {}, {
        o: item.is_std
      }, item.is_std ? {
        p: item.checked ? "../../static/icon/checked.png" : "../../static/icon/checkbox.png"
      } : {}, {
        q: common_vendor.t(item.exp_time),
        r: common_vendor.o(($event) => $options.checkedCoupon(index), index),
        s: index
      });
    }),
    ag: common_vendor.sr("couponPopup", "618774e2-2"),
    ah: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    }),
    ai: common_vendor.f($data.addrList, (item, index, i0) => {
      return common_vendor.e({
        a: item.id == $data.checkedAddr.id ? "../../static/icon/radioed.png" : "../../static/icon/radio.png",
        b: common_vendor.t(item.contact_name),
        c: common_vendor.t(item.contact_phone),
        d: item.is_default
      }, item.is_default ? {} : {}, {
        e: common_vendor.t(item.contact_province),
        f: common_vendor.t(item.contact_city),
        g: common_vendor.t(item.contact_area),
        h: common_vendor.t(item.contact_addr),
        i: index,
        j: common_vendor.o(($event) => $options.checkedAddrItem(item), index)
      });
    }),
    aj: common_vendor.sr("addrPopup", "618774e2-3"),
    ak: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    }),
    al: common_vendor.o(($event) => $options.closeAddFollow()),
    am: $data.followQrcode
  }, $data.followQrcode ? {
    an: $data.followQrcode
  } : {}, {
    ao: common_vendor.o(($event) => $options.saveImage()),
    ap: common_vendor.sr("addFollow", "618774e2-4"),
    aq: common_vendor.o($options.popupChange),
    ar: common_vendor.p({
      type: "center"
    })
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render]]);
wx.createPage(MiniProgramPage);
